Sherok

A new epic library for making python simpler.                 

Here is the documentation - https://github.com/SreehariTheProgrammer/SherokDocumentation/blob/main/README.md
                                                                                                            
________________________________________________________________________________________________